import { useMessage } from '/@/hooks/web/useMessage'
import { defHttp } from '/@/utils/http/axios'

const { createConfirm } = useMessage()

enum Api {
	list = '/dry/dryEquipment/list',
	listAll = '/dry/dryEquipment/listAll',
	save = '/dry/dryEquipment/add',
	edit = '/dry/dryEquipment/edit',
	deleteOne = '/dry/dryEquipment/delete',
	deleteBatch = '/dry/dryEquipment/deleteBatch',
	importExcel = '/dry/dryEquipment/importExcel',
	exportXls = '/dry/dryEquipment/exportXls',
}
/**
 * 导出api
 * @param params
 */
export const getExportUrl = Api.exportXls
/**
 * 导入api
 */
export const getImportUrl = Api.importExcel
/**
 * 列表接口
 * @param params
 */
export const list = (params) => defHttp.get({ url: Api.list, params })

/**
 * 所有机台
 * @param params
 */
export const listAll = (params) => defHttp.get({ url: Api.listAll, params })

/**
 * 删除单个
 */
export const deleteOne = (params, handleSuccess) => {
	return defHttp.delete({ url: Api.deleteOne, params }, { joinParamsToUrl: true }).then(() => {
		handleSuccess()
	})
}
/**
 * 批量删除
 * @param params
 */
export const batchDelete = (params, handleSuccess) => {
	createConfirm({
		iconType: 'warning',
		title: '确认删除',
		content: '是否删除选中数据',
		okText: '确认',
		cancelText: '取消',
		onOk: () => {
			return defHttp.delete({ url: Api.deleteBatch, data: params }, { joinParamsToUrl: true }).then(() => {
				handleSuccess()
			})
		},
	})
}
/**
 * 保存或者更新
 * @param params
 */
export const saveOrUpdate = (params, isUpdate) => {
	const url = isUpdate ? Api.edit : Api.save
	return defHttp.post({ url: url, params })
}
